# Citrobacter sedlakii NBRC 105722

This is model data for *Citrobacter sedlakii* NBRC 105722 and is based on the data from *Elucidating genomic gaps using phenotypic profiles* by Daniel Cuevas *et al.*

The file [Citrobacter_sedlakii_reactions.txt](Citrobacter_sedlakii_reactions.txt) contains a gap-filled set of reactions that will result in growth.

The file [Citrobacter_sedlakii.sbml](Citrobacter_sedlakii.sbml) is an SBML file that contains a gap filled set of reactions that will result in growth.

The two models were created independently, and thus contain different reactions.
